function [bestModelObs, bestModelQuest] = selectFinalModel(infoAccTree, infoAccNB, infoAccSVM)
%function [bestModelObs, bestModelQuest] = selectFinalModel(infoAccTree, infoAccNB, infoAccSVM)
%DESCRIPTION: Select the final model comparing the cross validation
%accuracy
%INPUTS:
%   - infoAccTree: Struct containing: Mean and standard deviation of accuracy
%   in observations and questionnaires. Decision Tree
%   - infoAccNB: Struct containing: Mean and standard deviation of accuracy
%   in observations and questionnaires. Naive Bayes
%   - infoAccSVM: Struct containing: Mean and standard deviation of accuracy
%   in observations and questionnaires. Support Vector Machine
%RETURN:
%   - bestModelObs: Name of the best model for observations
%   - bestModelQuest: Name of the best model for questionnaires
%Author: Bernat Carbons
%Modification Date: 04/07/2014

models={'Decision Tree', 'Naive Bayes', 'Support Vector Machine'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%OBSERVATIONS
avgAccObs(1)=infoAccTree.obsMeanAccuracy;
avgAccObs(2)=infoAccNB.obsMeanAccuracy;
avgAccObs(3)=infoAccSVM.obsMeanAccuracy;

stdAccObs(1)=infoAccTree.obsStandardDeviationAccuracy;
stdAccObs(2)=infoAccNB.obsStandardDeviationAccuracy;
stdAccObs(3)=infoAccSVM.obsStandardDeviationAccuracy;

%QUESTIONNAIRES
avgAccQuest(1)=infoAccTree.questMeanAccuracy;
avgAccQuest(2)=infoAccNB.questMeanAccuracy;
avgAccQuest(3)=infoAccSVM.questMeanAccuracy;

stdAccQuest(1)=infoAccTree.questStandardDeviationAccuracy;
stdAccQuest(2)=infoAccNB.questStandardDeviationAccuracy;
stdAccQuest(3)=infoAccSVM.questStandardDeviationAccuracy;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Select the model with high accuracy in observations
modelSel=find(avgAccObs==max(avgAccObs));
if length(modelSel)>1
    modelSel=find(stdAccObs==min(stdAccObs));%If equals, select low deviation
    if length(modelSel)>1
        modelSel=input(strcat('Select a model among:',32, ...
            num2str(modelSel),32,'->',32));
    end
end
       

%Display
display(strcat('Best model for observations:',32, models{modelSel}));
display(strcat('Accuracy in validation:',32, num2str(avgAccObs(modelSel))));

bestModelObs=models{modelSel};


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Select the model with high accuracy in questionnaires
modelSel=find(avgAccQuest==max(avgAccQuest));
if length(modelSel)>1
    modelSel=find(stdAccQuest==min(stdAccQuest));%If equals, select low deviation
    if length(modelSel)>1
        modelSel=input(strcat('Select a model among:',32, ...
            num2str(modelSel),32,'->',32));
    end
end
       


%Display
display(strcat('Best model for questionnaires:',32, models{modelSel}));
display(strcat('Accuracy in validation:',32, num2str(avgAccQuest(modelSel))));


bestModelQuest=models{modelSel};
