function [naiveBayes, crossValErrors] = accelNaiveBayesCreation(matrixFinal, ystr, algInd, orderSFS, indPartDay)
%function [naiveBayes, crossValErrors] = accelNaiveBayesCreation(matrixFinal, ystr, algInd, orderSFS, indPartDay)
%DESCRIPTION: Create three Naive Bayes models
%INPUTS:
%   - matrixFinal: Matrix where each column contains a predicting value and
%   each row is the associated instance
%   - ystr: Vector with instances (for each observation)
%   - algInd: Indices for Training
%   - orderSFS: Ordered features according to SFS
%   - indPartDay: Index part day feature
%RETURN:
%   - naiveBayes: Three types of Naive Bayes models
%   - crossValErrors: Cross Validation Errors of each model
%Author: Bernat Carbons
%Modification Date: 21/06/2014
             
rng(8000,'twister');
matrixSFS = matrixFinal(algInd, orderSFS);
ystrSFS = ystr(algInd);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%1. Distribution->Gaussian

%Vector with the features distribution
dist=repmat({'normal'},length(orderSFS),1);

if ~isempty(find(orderSFS==indPartDay, 1))
    dist{orderSFS==indPartDay}='mvmn';
end

naiveBayes{1}=fitNaiveBayes(matrixSFS, ystrSFS, 'Distribution', dist);


%Cross ValidationError

NBModel1ClassFun = @(xtrain,ytrain,xtest)...
    (predict(fitNaiveBayes(xtrain,ytrain,'Distribution',dist),xtest));

crossValErrors(1) = crossval('mcr',matrixSFS,ystrSFS,'Predfun', ...
    NBModel1ClassFun,'KFold',10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%2. Distribution-> Kernel smoothing density estimate. Kernel type-> Gaussian

%Vector with the features distribution
dist=repmat({'kernel'},length(orderSFS),1);
if ~isempty(find(orderSFS==indPartDay, 1))
    dist{orderSFS==indPartDay}='mvmn';
end


%Bandwidth vector
bw=zeros(1,length(orderSFS));

for in=1:length(orderSFS)
    [~,~,bw(in)]=ksdensity(matrixSFS(:,in),'kernel','normal');
end

naiveBayes{2}=fitNaiveBayes(matrixSFS, ystrSFS, 'Distribution', dist, ...
    'KSType', 'normal', 'KSWidth', bw);


NBModel2ClassFun = @(xtrain,ytrain,xtest)...
    (predict(fitNaiveBayes(xtrain,ytrain,'Distribution',dist, ...
    'KSType', 'normal', 'KSWidth', bw),xtest));

crossValErrors(2) = crossval('mcr',matrixSFS,ystrSFS,'Predfun', ...
    NBModel2ClassFun,'KFold',10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%3. Distribution-> Kernel smoothing density estimate. Kernel type-> Epanechnikov

%Vector with the features distribution--> is the same

%Bandwidth vector
bw=zeros(1,length(orderSFS));

for in=1:length(orderSFS)
    [~,~,bw(in)]=ksdensity(matrixSFS(:,in),'kernel','epanechnikov');
end

naiveBayes{3}=fitNaiveBayes(matrixSFS, ystrSFS, 'Distribution', dist, ...
    'KSType', 'epanechnikov', 'KSWidth', bw);

NBModel3ClassFun = @(xtrain,ytrain,xtest)...
    (predict(fitNaiveBayes(xtrain,ytrain,'Distribution',dist, ...
    'KSType', 'epanechnikov', 'KSWidth', bw),xtest));

crossValErrors(3) = crossval('mcr',matrixSFS,ystrSFS,'Predfun', ...
    NBModel3ClassFun,'KFold',10);



  










