function [naiveBayesSEL, crossValError] = selectNaiveBayes(naiveBayes, crossValErrors)
%function [naiveBayesSEL, crossValError] = selectNaiveBayes(naiveBayes, crossValErrors)
%DESCRIPTION: Select the optimal Naive Bayes
%INPUTS:
%   - naiveBayes: Three types of Naive Bayes models
%   - crossValErrors: Cross Validation Errors of each model
%RETURN:
%   - naiveBayesSEL: Selected Naive Bayes model
%   - crossValError: CrossValidation error of the selected Naive Bayes
%Author: Bernat Carbons
%Modification Date: 25/06/2014


%Get index of the categorical variable.

%Select the tree with small Cross Validation Error
NBSel=find(crossValErrors==min(crossValErrors));
if length(NBSel)>1
    NBSel=input(strcat('Select a Naive Bayes model among:',32, ...
        num2str(NBSel),32,'->',32));
end
       
naiveBayesSEL=naiveBayes{NBSel};
crossValError=crossValErrors(NBSel);


%Display
if NBSel==1
    display(strcat('Naive Bayes with Distribution:',32,naiveBayesSEL.Dist{1}));
else
    display(strcat('Naive Bayes with Distribution:',32,naiveBayesSEL.Dist{end},32,'and Kernel type:',32,naiveBayesSEL.Params{end}.Kernel));
end

display(strcat('Cross Validation Error:',32, num2str(crossValError)));

