function matrixScaled = scalingData (matrixFinal, orderSFS, indPartDay)
%function matrixScaled = scalingData (matrixFinal, orderSFS, indPartDay)
%DESCRIPTION: Scaling matrix and transform catgeorical feature
%INPUTS:
%   - matrixFinal: Matrix where each column contains a predicting value and
%   each row is the associated instance
%   - algInd: Indices for Algorithm
%   - orderSFS: Ordered features according to SFS
%RETURN:
%   - matrixScaled: Scaled matrix (from -1 to 1)
%Author: Bernat Carbons
%Modification Date: 24/06/2014


%Get the desired values of the matrix
matrixSFS = matrixFinal(:, orderSFS);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Process the categorical feature
%Create three vectors. (1,0,0), (0,1,0), (0,0,1)
if ~isempty(find(orderSFS==indPartDay, 1))
    indPDsfs=find(orderSFS==indPartDay);
    vPD=matrixSFS(:,indPDsfs);
    pdNumSel=unique(vPD);
    v=[];
    for in=1:length(pdNumSel)
        v=[v vPD==pdNumSel(in)];   
    end
    matrixSFS=[matrixSFS(:,1:indPDsfs-1), v, matrixSFS(:,indPDsfs+1:end)];
    
end

%Scaling data from -1 to 1
[rows,~]=size(matrixSFS);
colMax=max(abs(matrixSFS),[],1);% take max absolute value to account for negative numbers
matrixScaled=matrixSFS./repmat(colMax,rows,1);





