function [SVMSEL, SVMparam, crossValError] = selectSVM(SVMs,SVMsParam, crossValErrors)
%function [SVMSEL, SVMparam, crossValError] = selectSVM(SVMs,SVMsParam, crossValErrors)
%DESCRIPTION: Select the optimal SVM
%INPUTS:
%   - SVMs: Three types of SVM to evaluate
%   - SVMsParam: Parameters of the SVM models. 0 Otherwise
%   - crossValErrors: Cross Validation Errors of each model
%RETURN:
%   - SVMsel: Selected SVM
%   - SVMparam: Selected parameter
%   - crossValError: CrossValidation error of the selected tree
%Author: Bernat Carbons
%Modification Date: 26/06/2014


%Select the tree with small Cross Validation Error
SVMind=find(crossValErrors==min(crossValErrors));
if length(SVMind)>1
    SVMind=input(strcat('Select a SVM among:',32, ...
        num2str(SVMind),32,'->',32));
end
       
SVMSEL=SVMs{SVMind};
SVMparam=SVMsParam{SVMind};
crossValError=crossValErrors(SVMind);

%Display
kernels={'Radial Basis Function', 'Linear', 'Polynomial'};

display(strcat('SVM with kernel:',32,kernels{SVMind}));
display(strcat('Cross Validation Error:',32, num2str(crossValError)));
