function state=weekSumCSVdoc(dataAnthropoSQL,dataActivitiesSQL,dataActivityMets,resfilename,idUser)
%function state=weekSumCSVdoc(dataAnthropoSQL,dataActivitiesSQL,dataActivityMets,resfilename,idUser)
%DESCRIPTION: Annex 3. Week summary of the activities carried out. Single 
%User. Write excel (*.csv) file
%INPUTS:
%   - dataAnthropoSQL: Antrhropometric data SQL
%   - dataActivitiesSQL: Indicated activities (questionnaires) SQL
%   - dataActivityMets: All possible activities, their identifiers and METs
%   - resfilename: Name of the output file
%   - idUser: Desired user's identifier
%RETURN:
%   - state: Succes or fail
%Author: Bernat Carbons
%Modification Date: 06/06/2014


%heartrate=0;
%idUser=55;
[~, tdays, thours]=amountQuestData(dataActivitiesSQL,idUser);

[height,weight,age,gender] = get_anthroData(dataAnthropoSQL, idUser);

%Get the BMR
BMR=basalMR(weight,height,age,gender);

%Transform BMR kcal to METs
mets=kcal2met(BMR, 1, weight);

%Load the Activitats-MET.txt file
%fileComplete = fullfile('/Users/Bernat/Dropbox/Bernat/4B/TFG/', 'ActivitatsMETaccents.txt');
%[idActTXT, actPpalTXT, subActPpalTXT, metsTXT]=importactMETs(fileComplete);

%Get all possible activities
idActTXT=dataActivityMets{1};
actPpalTXT=dataActivityMets{2};
subActPpalTXT=dataActivityMets{3};
metsTXT=dataActivityMets{4};

%Set some parameters
numDays=7;
numActs=length(idActTXT);
acts=cell(numActs,numDays*2+2);

%Get the indicated activities SQL
%actsPpal=indicatedActivitySQLnumber(dataActivitiesSQL,dataActivityMets,idUser,'actPpal');
actsSec=indicatedActivitySQLnumber(dataActivitiesSQL,dataActivityMets,idUser,'subActPpal');
time=indicatedActivitySQL(dataActivitiesSQL,idUser,'tiempoRegistrado');

numDay=zeros(1,length(time));
nameDay=cell(1,length(time));
totalhours=zeros(1,length(time));

for in=1:length(time)
    [totalhours(in), numDay(in), nameDay{in}]=getSQLhourNameDay(time(in));
end

%Get only a single week
if tdays>=7
    lasts=numDay(end-((tdays-numDays)*24*4+thours*4)+1:end);
    
    while((length(nameDay)-length(numDay))~= length(lasts))
        aux=find(lasts==numDay(in));
        numDay=numDay(1:end-numel(aux));
    end
end

%Create the *.csv document
header=strcat('\tMonday\t\tTuesday\t\tWednesday\t\tThursday\t\tFriday\t\tSaturday\t\tSunday\t\tWEEK\n');
fid = fopen(resfilename, 'w');
fprintf(fid,header);
header=strcat('ACT\tn/4\tMETs\tn/4\tMETs\tn/4\tMETs\tn/4\tMETs\tn/4\tMETs\tn/4\tMETs\tn/4\tMETs\tSum\n');
fprintf(fid,header);

%Find activities with subActivity NULL
actsNoSubACT=find(strcmpi(dataActivityMets{3},'NULL')==1);

%Activities and METs
for in=1:numActs
    if isempty(find(in==actsNoSubACT,1))%Activities without subAct
        acts{in}=subActPpalTXT{in};
    else
        acts{in}=actPpalTXT{in};
    end
    %fprintf(fid,'%s\t',acts{in});
    for ini=1:2:numDays*2
        posDay= (round(ini/2)==numDay);
        actsDay=actsSec(posDay);
        n4=numel(find(actsDay==idActTXT(in)));
        acts{in,ini+1}=n4/4;
        acts{in,ini+2}=n4/4*metsTXT(in);
        %fprintf(fid,'%.2f\t%.2f\t',acts{in,ini+1},acts{in,ini+2});
    end
    actsaux=acts(in,3:2:end);
    actsaux=cell2mat(actsaux);
    sumWeek=sum(actsaux);
    acts{in,end}=sumWeek;
    %fprintf(fid,'%.2f\n',acts{in,end});
end

%Replace empty activites
sumWeeks=acts(:,end);
sumWeeks=cell2mat(sumWeeks);
noEmptys0=find(sumWeeks);
for in=1:length(sumWeeks)
    if sumWeeks(in)==0
        noEmptys=find(sumWeeks);
        firstNoEmpty=noEmptys(find(noEmptys>in,1));
        if isempty(firstNoEmpty)
            sumWeeks(in:end)=[];
            acts=acts(1:in-1,:);
            break;
        else
            acts(in,:)=acts(firstNoEmpty,:);
            acts(firstNoEmpty,:)=[];
            sumWeeks(in)=sumWeeks(firstNoEmpty);
            sumWeeks(firstNoEmpty)=[];     
        end
    end
end
numActs=length(sumWeeks);

% in=1;
% while(in<length(sumWeeks))
%     if sumWeeks(in)==0
%         noEmptys=find(sumWeeks);
%         firstNoEmpty=noEmptys(find(noEmptys>in,1));
%         if isempty(firstNoEmpty)
%             sumWeeks(in:end)=[];
%             acts=acts(1:in-1,:);
%             in=length(sumWeeks);
%         else
%             acts(in,:)=acts(firstNoEmpty,:);
%             acts(firstNoEmpty,:)=[];
%             sumWeeks(in)=sumWeeks(firstNoEmpty);
%             sumWeeks(firstNoEmpty)=[];      
%         end
%     end
%     in=in+1;
% end

%Print DATA.
for in=1:numActs;
    if isempty(find(in==actsNoSubACT,1))%Activities without subAct
        fprintf(fid,'%s: ',actPpalTXT{noEmptys0(in)});
    end
    fprintf(fid,'%s\t',acts{in,1});
    for ini=2:numDays*2+2
        fprintf(fid,'%.2f\t',acts{in,ini});
    end
    fprintf(fid,'\n');
end




%SUM activities and METs x day due questionnaires
actsaux=acts(:,2:end-1);
actsaux=cell2mat(actsaux);
sumHMxDay=sum(actsaux);
    
fprintf(fid,'Sum Activities\t');
for in=1:numDays*2
    fprintf(fid,'%.2f\t',sumHMxDay(in));
end

%TOTAL WEEK (TW) and AVERAGE DAILY (AD)
actsaux=acts(:,end);
actsaux=cell2mat(actsaux);
tw=sum(actsaux);
ad=tw/7;
fprintf(fid,'TW=%.2f AD=%.2f\n',tw,ad);


%MEAN activities and METs x day
meanHMxDay=sumHMxDay/24;

fprintf(fid,'Mean Activities\t');
for in=1:numDays*2
    fprintf(fid,'%.2f\t',meanHMxDay(in));
end


%AVERAGE X HOUR (AH)
ah=ad/24;
fprintf(fid,'AH=%.2f\n', ah);


%Basal Metabolic Rate (BMR)
fprintf(fid,'BMR\t');
bmr=zeros(1,numDays+1);
bmr(1:end-1)=mets;
bmr(end)=sum(bmr(1:end-1));
for in=1:numDays
    fprintf(fid,'\t%.2f\t',bmr(in));
end
fprintf(fid,'%.2f\n',bmr(end));


%Thermic Effect of Food (TEF)
fprintf(fid,'TEF\t');
tef=zeros(1,numDays+1);
tef(1:end-1)=getTEF(bmr(1:end-1),sumHMxDay(2:2:end));
%tef(1:end-1)=0.1*(bmr(1:end-1)+sumHMxDay(2:2:end));
tef(end)=sum(tef(1:end-1));
for in=1:numDays
    fprintf(fid,'\t%.2f\t',tef(in));
end
fprintf(fid,'%.2f\n\n',tef(end));


%TOTAL SUM
fprintf(fid,'TOTAL SUM\t');
total=zeros(1,numDays+1);
total(1:end-1)=sumHMxDay(2:2:end)+bmr(1:end-1)+tef(1:end-1);
total(end)=sum(total(1:end-1));
for in=1:numDays
    fprintf(fid,'\t%.2f\t',total(in));
end
fprintf(fid,'%.2f',total(end));

fclose(fid);

state='Week summary of the activities CSV file built successfully';