function values=binnedDistribution(data,numBins,optPlot)
%function values=binnedDistribution(data,numBins,optPlot)
%DESCRIPTION: Compute a binned distribution
%INPUTS:
%   - data: Data values
%   - numBins: Number of bins
%   - optPlot: 0-->No plot. 1-->Plot
%RETURN:
%   - values: vector of numBins length containing the percent of values to
%   each Bin


binEdges = linspace(min(data),max(data),numBins+1);
aj = binEdges(1:end-1);     %# bins lower edge
bj = binEdges(2:end);       %# bins upper edge
cj = (aj+bj)./2;      %# bins center

% assign values to bins
[~,binIdx] = histc(data, [binEdges(1:end-1) Inf]);
%[~,binIdx] = histc(data, binEdges(1:end));

% count number of values in each bin
values = accumarray(binIdx, 1, [numBins 1], @sum);
values=values/length(data);

if optPlot
    plot histogram
    bar(cj,values,'hist')
    set(gca, 'XTick',binEdges, 'XLim',[binEdges(1) binEdges(end)])
    xlabel('Bins'), ylabel('Fraction'), title('histogram of measured bacterial')
end

