function kcalhour=hr2kcal(bpm, weight, age, gender)
%function kcalhour=hr2kcal(bpm, weight, age, gender)
%DESCRIPTION: Obtain the burned kcal using the Heart Rate and
%anthropometric data. Only valid when HR>60%HRmax
%INPUTS:
%   - bpm: Heart Rate in bpm
%   - weight: Weight in kg
%   - age: age in years
%   - gender: 1-->Male. 0-->Female
%RETURN:
%   - kcalhour: burned kcal/hour
%Author: Bernat Carbons
%Modification Date: 27/04/2014

hrmax=getHRmax(age);
kcalmod=find((0.6*hrmax>bpm),1);

if isempty(kcalmod)==0
    kcalhour='Error in kcalhour function, bpm is lower than 60% of HRmax';
    display(kcalhour);
    return;
end

if gender
    kcalhour=(-55.0969 + 0.6309*bpm + (0.1988*weight) + (0.2017*age))/4.184*60;
else
    kcalhour=(-20.4022 + 0.4472*bpm - (0.1263*weight) + (0.074*age))/4.184*60;
end