function [algInd, tunInd, testInd] = divideData(algPcent, tunPcent, testPcent, matrixFinal, ystr, numObsQuest)
%function [holdoutCVP, algInd, tunInd, testInd] = divideData(algPcent, tunPcent, testPcent, matrixFinal, ystr)
%DESCRIPTION: Make a data partition: 1.Choose Algorithm (training), 2.Tunning algorithm (validation), 3. Test algorithm 
%INPUTS:
%   - algPcent: tant per cent of data for Training 
%   - tunPcent: tant per cent of data for Validation
%   - testPcent: tant per cent of data for Testing
%   - matrixFinal: Matrix with all the features and observations
%   - ystr: Vector with instances (for each observation)
%   - numObsQuest: Number of observations for questionnaire
%RETURN:
%   - algInd: Indices for Training
%   - tunInd: Indices for Validation
%   - testInd: Indices for Testing
%Author: Bernat Carbons
%Modification Date: 19/06/2014


[numRows,~]=size(matrixFinal);

%To divide data equally into groups of 20% of total. 
while (0.2*numRows~=floor(0.2*numRows))
    numRows=numRows-numObsQuest;
end

ystr=ystr(1:numRows);

algPcent=algPcent/100;
tunPcent=tunPcent/100;
testPcent=testPcent/100;

%Data train=algorithm+tunning
trainPcent=algPcent+tunPcent;
%Divide Data into Training set and Test set
rng(8000,'twister');

%Get index every 15 minutes to have observationes every 15 minutes jointly.
indRandom=1:1:ceil(numRows/numObsQuest);

holdoutINDX= cvpartition(ystr((indRandom-1)*numObsQuest+1), ...
    'holdout',round(testPcent*length(indRandom)));


%TEST INDICES
testInd15=find(holdoutINDX.test); %Test indices
testInd=[];
tunAlgInd15=find(holdoutINDX.training);

for in=1:length(testInd15)
    testInd=[testInd ((testInd15(in)-1)*numObsQuest+1):(testInd15(in)*numObsQuest)];   
end



%Validation and training indices

indRandom=indRandom(holdoutINDX.training);

holdoutINDX= cvpartition(ystr((indRandom-1)*numObsQuest+1), ...
    'holdout',round(tunPcent/trainPcent*length(indRandom)));

algInd15=indRandom(holdoutINDX.training);%Algorithm indices
tunInd15=indRandom(holdoutINDX.test);%Tunning indices

%VALIDATION INDICES
tunInd=[];
for in=1:length(tunInd15)
    tunInd=[tunInd ((tunInd15(in)-1)*numObsQuest+1):(tunInd15(in)*numObsQuest)];   
end


%TRAINING INDICES
algInd=[];
for in=1:length(algInd15)
    algInd=[algInd ((algInd15(in)-1)*numObsQuest+1):(algInd15(in)*numObsQuest)];   
end