function [matrixFinal, ystr, ynum]=accelFeatureExtraction(dataAccel,dataActivitiesSQL,dataActivityMets,opsFE,idUser,optPlot, questDur)
%function [matrixFinal, ystr, ynum]=accelFeatureExtraction(dataAccel,dataActivitiesSQL,dataActivityMets,opsFE,idUser,optPlot, questDur)
%DESCRIPTION: Compute the feature extraction for the selected user using
%accelerometer data
%INPUTS:
%   - dataAccel: Acclerometer data
%   - dataActivitiesSQL: Indicated activities (questionnaires) SQL
%   - dataActivityMets: All possible activities, their identifiers and METs
%   - opsFE: Cell containing the feature extraction parameters:
%   opsFE={fs wwidth wsmall overlap optionOverlap orderBurg numBins numFeat}
%   - idUser: Desired user's identifier
%   - optPlot: 0-->No plot. 1-->Plot
%   - questDur: Duration of one questionnaire in minutes
%RETURN:
%   - matrixFinal: Matrix where each column contains a predicting value and
%   each row is the associated instance
%   - ystrSingle: Instances (strings)
%   - ynumSingle: Instances (numbers)
%Author: Bernat Carbons
%Modification Date: 31/05/2014


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Inicialization of the variables

%Desired sample frequency
fs=opsFE{1};
%Window width (seconds)
wwidth=opsFE{2};
%Small Window width (seconds)
wsmall=opsFE{3};
%Overlap
overlap=opsFE{4};
option=opsFE{5};
%Order Filter AR coeffients
orderBurg=opsFE{6};
%NumBins for Binned Distribution Feature
numBins=opsFE{7};
%Number of features
numFeat=opsFE{8};

%Number the samples for each questionnaire
nQuest=questDur*60*fs;

%Number samples/window
N=wwidth*fs;
%N=2^nextpow2(N);%To get a 2 power for faster fft


%Gravity
g=9.8;


%Get Data from Activity Mets file
actPpalTXT=dataActivityMets{2};
subActPpalTXT=dataActivityMets{3};

matrixFinal=[];
ystr=[];
ynum=[];
totalTime=0;


%Load time of the activities for the selected user
time_user=indicatedActivitySQL(dataActivitiesSQL,idUser,'tiempoRegistrado');
for ini=1:length(time_user)
    time_user(ini)=getSQLhourNameDay(time_user(ini));
end


%Get the sub activities for the selected user
subActPpalNum=indicatedActivitySQLnumber(dataActivitiesSQL, ...
    dataActivityMets, idUser,'subActPpal');%Get activity number



for in=1:length(dataAccel)
    
    %Load the Acceleromter data
    %[ax,ay,az,t,date]=accelData(fs,file,pathname);
    ax=dataAccel{in}{1};
    ay=dataAccel{in}{2};
    az=dataAccel{in}{3};
    t=dataAccel{in}{4};
    date=dataAccel{in}{5};   
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %PROCESSING
    t0=getSQLhourNameDay(date);
    tf=t0+t(end)/3600;
    
    %15 minutes jointly
    tini=round((questDur-mod(t0*60,questDur))*60);
    indTini=tini*fs+1;
    
    tfin=round(t(end)-mod(tf*60,questDur)*60);
    indTfini=tfin*fs+1;

    t=t(indTini:indTfini-1);
    if isempty(t)
        beep;
        beep;
        continue;
    end
    ax=ax(indTini:indTfini-1);
    ay=ay(indTini:indTfini-1);
    az=az(indTini:indTfini-1);
    
    t=t./3600; %Convert seconds to hours
    tf=t0+t(end);
    t0=t0+t(1);
    
    
    t0Curr=gethourNum(date);
    tCurr=t0Curr+t;
    
    %Part of the day%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %06h-14h:Morning-->1
    %14h-22h:Afternoon-->2
    %21-06h:Night-->3
    partDay=zeros(1,length(tCurr));
    partDay(tCurr>=6&tCurr<14)=0;
    partDay(tCurr>=14&tCurr<22)=1;
    partDay(tCurr>=22&tCurr<6)=2;
    
    %Get the desired time from questionnaires and find the postions where the
    %activity change
    indexTimeSQL=find(time_user>=t0&time_user<tf);
    if isempty(indexTimeSQL)
        %indexTimeSQL=find(time_user<t0,1,'last');
        continue;
    end
    
    %Get the id activity number for each selected questionnaire
    timeSel=subActPpalNum(indexTimeSQL);
    
    %Classify the indices for each activity
    numActs=max(subActPpalNum);%Get the different activities
    indexTacts=cell(1,numActs);
    for ini=1:length(indexTimeSQL)
        indexTacts{timeSel(ini)}=[indexTacts{timeSel(ini)},(ini-1)*nQuest+1:ini*nQuest];
    end
    
    %Find the no empty activities
    noEmptyAct=[];
    for ini=1:numActs
        if isempty(indexTacts{ini})==0
            noEmptyAct=[noEmptyAct ini];
        end
    end
    
    
    %Create the struct for the selected accelerometer data and covert hours to
    %seconds
    accel=cell(1,length(noEmptyAct));
    index=1;
    for ini=1:numActs
        if isempty(find(noEmptyAct==ini, 1))==0
            accel{index}=struct('MainActivity',actPpalTXT(noEmptyAct(index)), ...
                'SecActivity',subActPpalTXT(noEmptyAct(index)),'id',ini, ...
                'timeStamp',(t(indexTacts{noEmptyAct(index)})-t(1))*3600, ...
                'partDay',partDay(indexTacts{noEmptyAct(index)}),'ax', ...
                ax(indexTacts{noEmptyAct(index)}),'ay', ay(indexTacts{noEmptyAct(index)}), ...
                'az',az(indexTacts{noEmptyAct(index)}));
            index=index+1;
        end
    end
    numActs=length(noEmptyAct);
    
    
    
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %FEATURE GENERATION
    %Applying the window
    for ini=1:numActs
            
        %Number of questionnaires for selected activity
        numQuest=length(accel{ini}.timeStamp)/nQuest;
        Yt=[];
        Yx=[];
        Yy=[];
        Yz=[];
        Ypd=[];
        for inin=1:numQuest
            %timeStamp
            Yt=[Yt,buffer(accel{ini}.timeStamp((inin-1)*nQuest+1:inin*nQuest), ...
                N, overlap*N, option)];
            %ax
            Yx=[Yx,buffer(accel{ini}.ax((inin-1)*nQuest+1:inin*nQuest), N, ...
                overlap*N, option)];
            %ay
            Yy=[Yy,buffer(accel{ini}.ay((inin-1)*nQuest+1:inin*nQuest), N, ...
                overlap*N, option)];
            %az
            Yz=[Yz,buffer(accel{ini}.az((inin-1)*nQuest+1:inin*nQuest), N, ...
                overlap*N, option)];
            %partDay
            Ypd=[Ypd,buffer(accel{ini}.partDay((inin-1)*nQuest+1:inin*nQuest), ...
                N, overlap*N,option)];
        end
        accel{ini}.timeStamp=Yt;
        accel{ini}.ax=Yx;
        accel{ini}.ay=Yy;
        accel{ini}.az=Yz;
        accel{ini}.partDay=Ypd;
    end
    
    %Final matrix creation
    %numAxis=3;
    [~,numRows]=size(accel{1}.ax);%Return[numRows,numcols] but numCols is numRows in matrixAccel
    %numCols=numAxis*numFeat;
    matrixFinalSingle=zeros(numRows,numFeat);
    %Vector. Activity which corresponds.
    ystrSingle=cell(numRows,1);
    ynumSingle=zeros(numRows,1);
    
    numRows=0;
    previous=0;
    
    %Filling final matrix
    for ini=1:numActs
        previous=previous+numRows;
        [~,numRows]=size(accel{ini}.ax);
        
        for row=1:numRows
            %Fill activity
            ystrSingle{row+previous}=strcat(accel{ini}.MainActivity,':', ...
                accel{ini}.SecActivity);
            ynumSingle(row+previous)=accel{ini}.id;
            
            %pos=1;
            
            %TEMPORAL FEATURES
            %1.Mean%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,1)=mean(accel{ini}.ax(:,row));
            %accel{in}.ax(:,row)=accel{in}.ax(:,row)-mean(accel{in}.ax(:,row));
            matrixFinalSingle(row+previous,2)=mean(accel{ini}.ay(:,row));
            %accel{in}.ay(:,row)=accel{in}.ay(:,row)-mean(accel{in}.ay(:,row));
            matrixFinalSingle(row+previous,3)=mean(accel{ini}.az(:,row));
            %accel{in}.az(:,row)=accel{in}.az(:,row)-mean(accel{in}.az(:,row));
            matrixFinalSingle(row+previous,4)=sqrt(matrixFinalSingle(row+previous, ...
                1)^2+matrixFinalSingle(row+previous,2)^2+matrixFinalSingle(row+previous,3)^2);
            
            %2.Variance%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,5)=var(accel{ini}.ax(:,row));
            matrixFinalSingle(row+previous,6)=var(accel{ini}.ay(:,row));
            matrixFinalSingle(row+previous,7)=var(accel{ini}.az(:,row));
            
            %3.Time Between peaks to see the periodicity%%%%%%%%%%%%%%%%%%%%%%%
            freqs=getFreq([(accel{ini}.ax(:,row)),(accel{ini}.ay(:,row)), ...
                (accel{ini}.az(:,row))],(accel{ini}.timeStamp(:,row)));
            matrixFinalSingle(row+previous,8)=freqs(1);
            matrixFinalSingle(row+previous,9)=freqs(2);
            matrixFinalSingle(row+previous,10)=freqs(3);
            
            %4.Correlation pair axes%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            R=corrcoef([accel{ini}.ax(:,row),accel{ini}.ay(:,row),accel{ini}.az(:,row)]);
            %ax,ay
            matrixFinalSingle(row+previous,11)=R(1,2);
            %ax,az
            matrixFinalSingle(row+previous,12)=R(1,3);
            %ay,az
            matrixFinalSingle(row+previous,13)=R(2,3);
            
            %5.Mean Trend%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            Y=buffer(accel{ini}.ax(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=mean(Y);
            matrixFinalSingle(row+previous,14)=sum(abs(diff(Y)));
            %ay
            Y=buffer(accel{ini}.ay(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=mean(Y);
            matrixFinalSingle(row+previous,15)=sum(abs(diff(Y)));
            %az
            Y=buffer(accel{ini}.az(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=mean(Y);
            matrixFinalSingle(row+previous,16)=sum(abs(diff(Y)));
            
            %6.Windowed Mean difference%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            Y=buffer(accel{ini}.ax(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=mean(Y);
            matrixFinalSingle(row+previous,17)=sum(abs(matrixFinalSingle(row+previous,1)-Y));
            %ay
            Y=buffer(accel{ini}.ay(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=mean(Y);
            matrixFinalSingle(row+previous,18)=sum(abs(matrixFinalSingle(row+previous,2)-Y));
            %az
            Y=buffer(accel{ini}.az(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=mean(Y);
            matrixFinalSingle(row+previous,19)=sum(abs(matrixFinalSingle(row+previous,3)-Y));
            
            %7.Variance Trend%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            Y=buffer(accel{ini}.ax(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=var(Y);
            matrixFinalSingle(row+previous,20)=sum(abs(diff(Y)));
            %ay
            Y=buffer(accel{ini}.ay(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=var(Y);
            matrixFinalSingle(row+previous,21)=sum(abs(diff(Y)));
            %az
            Y=buffer(accel{ini}.az(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=var(Y);
            matrixFinalSingle(row+previous,22)=sum(abs(diff(Y)));
            
            %8.Windowed Variance difference%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            Y=buffer(accel{ini}.ax(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=var(Y);
            matrixFinalSingle(row+previous,23)=sum(abs(matrixFinalSingle(row+previous,5)-Y));
            %ay
            Y=buffer(accel{ini}.ay(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=var(Y);
            matrixFinalSingle(row+previous,24)=sum(abs(matrixFinalSingle(row+previous,6)-Y));
            %az
            Y=buffer(accel{ini}.az(:,row),wsmall*fs);%To obtain always 0.5 seconds
            Y=var(Y);
            matrixFinalSingle(row+previous,25)=sum(abs(matrixFinalSingle(row+previous,7)-Y));
            
            %9.Maximum Difference Acceleration%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,26)=max(accel{ini}.ax(:,row))-min(accel{ini}.ax(:,row));
            matrixFinalSingle(row+previous,27)=max(accel{ini}.ay(:,row))-min(accel{ini}.ay(:,row));
            matrixFinalSingle(row+previous,28)=max(accel{ini}.az(:,row))-min(accel{ini}.az(:,row));
            matrixFinalSingle(row+previous,29)=sqrt(matrixFinalSingle(row+previous, ...
                29)^2+matrixFinalSingle(row+previous,30)^2+matrixFinalSingle(row+previous,31)^2);
            
            %10.Signal Magnitude Area%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,30)=sum(sum(abs([accel{ini}.ax(:,row), ...
                accel{ini}.ay(:,row),accel{ini}.az(:,row)])));
            
            %11.Tilt Angle (TA)%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,31)=acos(mean(accel{ini}.ax(:,row))./g);
            matrixFinalSingle(row+previous,32)=acos(mean(accel{ini}.ay(:,row))./g);
            matrixFinalSingle(row+previous,33)=acos(mean(accel{ini}.az(:,row))./g);
            
            %12.AR coefficients (Burgs)%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            [arCoef,noiseVar]=arburg(accel{ini}.ax(:,row), orderBurg);
            matrixFinalSingle(row+previous,34)=arCoef(2);
            matrixFinalSingle(row+previous,35)=arCoef(3);
            matrixFinalSingle(row+previous,36)=arCoef(4);
            matrixFinalSingle(row+previous,37)=noiseVar;
            %ay
            [arCoef,noiseVar]=arburg(accel{ini}.ay(:,row), orderBurg);
            matrixFinalSingle(row+previous,38)=arCoef(2);
            matrixFinalSingle(row+previous,39)=arCoef(3);
            matrixFinalSingle(row+previous,40)=arCoef(4);
            matrixFinalSingle(row+previous,41)=noiseVar;
            %az
            [arCoef,noiseVar]=arburg(accel{ini}.az(:,row), orderBurg);
            matrixFinalSingle(row+previous,42)=arCoef(2);
            matrixFinalSingle(row+previous,43)=arCoef(3);
            matrixFinalSingle(row+previous,44)=arCoef(4);
            matrixFinalSingle(row+previous,45)=noiseVar;
            
            %13. Part of the day%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,46)=accel{ini}.partDay(1,row);
            
            %14. Binned Distribution%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            values=binnedDistribution(accel{ini}.ax(:,row),numBins,optPlot);
            for jn=1:numBins
                matrixFinalSingle(row+previous,46+jn)=values(jn);
            end
            %ay
            values=binnedDistribution(accel{ini}.ay(:,row),numBins,optPlot);
            for jn=1:numBins
                matrixFinalSingle(row+previous,56+jn)=values(jn);
            end
            %az
            values=binnedDistribution(accel{ini}.az(:,row),numBins,optPlot);
            for jn=1:numBins
                matrixFinalSingle(row+previous,66+jn)=values(jn);
            end
            
            
            
            %FREQUENCY FEATURES
            %15.FFT Spectral energy%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            matrixFinalSingle(row+previous,77)=(sum(abs(fft(accel{ini}.ax(:,row))).^2))/N;
            matrixFinalSingle(row+previous,78)=(sum(abs(fft(accel{ini}.ay(:,row))).^2))/N;
            matrixFinalSingle(row+previous,79)=(sum(abs(fft(accel{ini}.az(:,row))).^2))/N;
            
            %16.XY XZ YZ Energy Uncorrelated%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %XY
            matrixFinalSingle(row+previous,80)=(2-matrixFinalSingle(row+previous, ...
                11))*(matrixFinalSingle(row+previous,50)+matrixFinalSingle(row+previous,51));
            %XZ
            matrixFinalSingle(row+previous,81)=(2-matrixFinalSingle(row+previous, ...
                12))*(matrixFinalSingle(row+previous,50)+matrixFinalSingle(row+previous,52));
            %YZ
            matrixFinalSingle(row+previous,82)=(2-matrixFinalSingle(row+previous, ...
                13))*(matrixFinalSingle(row+previous,51)+matrixFinalSingle(row+previous,52));
            
            %17.Frequency Domain Entropy%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %ax
            P=abs(fft(accel{ini}.ax(:,row))).^2;
            P=P/sum(P);%Normalization
            matrixFinalSingle(row+previous,83)=-(P'*log2(P))/log2(length(P));%Entropy Calculation and normalize again
            %ay
            P=abs(fft(accel{ini}.ay(:,row))).^2;
            P=P/sum(P);%Normalization
            matrixFinalSingle(row+previous,84)=-(P'*log2(P))/log2(length(P));%Entropy Calculation and normalize again
            %az
            P=abs(fft(accel{ini}.az(:,row))).^2;
            P=P/sum(P);%Normalization
            matrixFinalSingle(row+previous,85)=-(P'*log2(P))/log2(length(P));%Entropy Calculation and normalize again
            
        end
        
    end
    
    %To avoid complex numbers
    matrixFinalSingle(imag(matrixFinalSingle)>0)=0;
    matrixFinalSingle=real(matrixFinalSingle);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Total Time
    [row, ~]=size(matrixFinalSingle);
    totalTimeSingle=row*wwidth/3600;
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Creating the final matrix joining overall data
    beep;
    %[matrixAux, ystrSingleAux, ynumSingleAux, totalTimeSingleAux]=accelDataTransform(dataAccel{in},dataActivitiesSQL,dataActivityMets,idUser)
    matrixFinal=[matrixFinal;matrixFinalSingle];
    ystr=[ystr;ystrSingle];
    ynum=[ynum;ynumSingle];
    totalTime=totalTime+totalTimeSingle;
   % beep;
    
    
end