function [numSelFeat, orderSFS, MCEsfs] = accelFeatureSelection(matrixFinal, ystr)
%function [numSelFeat, orderRelief, weightRelief, MCErelief, orderSFS, MCEsfs] = accelFeatureSelection(matrixFinal, ystr)
%DESCRIPTION: Feature Selection. Relief-F (Filter Method) and Sequential Feature
%Selection (SFS)
%INPUTS:
%   - matrixFinal: Matrix where each column contains a predicting value and
%   each row is the associated instance
%   - ystr: Vector with instances (for each observation)
%RETURN:
%   - numSelFeat: Amount of selected features
%   - orderSFS: Ordered features according to SFS
%   - MCEsfs: MisClassification Error for SFS 
%Author: Bernat Carbons
%Modification Date: 02/06/2014

rng(8000,'twister');

[numRows,~]=size(matrixFinal);

holdoutCVP = cvpartition(ystr,'holdout',round(0.2*numRows));
dataTrain = matrixFinal(holdoutCVP.training,:);
ystrTrain = ystr(holdoutCVP.training);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Relief-F
%Compute the Relief-F method to order the features (relevance) without
%considering dependence within other

%[ranked, weight]=relieff(dataTrain, ystrTrain, 10);
%beep;
load('ranked_weight_50.mat');


%Compute the Mis Classification Error (MCE)
numFeat=floor(length(ranked)*0.75);% 75% of total

%numMCE=floor(numFeat/3);
numMCE=numFeat;

testMCE =zeros(1,numMCE);
nfs = 1:1:numFeat;
classf = @(xtrain,ytrain,xtest,ytest) ...
             sum(~strcmp(ytest,classify(xtest,xtrain,ytrain,'linear')));
for i=1:numMCE
   fs = ranked(1:nfs(i));
   testMCE(i) = crossval(classf,matrixFinal(:,fs),ystr,'partition',holdoutCVP)...
       /holdoutCVP.TestSize;
end


figure;
plot(nfs, testMCE,'o');
xlabel('Number of Features');
ylabel('MisClasification Error (MCE)');
legend({'MCE on the test set'},'location','NW');
title('Simple Filter Feature Selection Method - Relief-F');
hold on;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Applying SFS (to consider interaction between features)

%Generate a stratified 10-fold partition for the training set
tenfoldCVP = cvpartition(ystrTrain,'kfold',10);

%Select the first 75% features
fs1 = ranked(1:numFeat);

%Apply SFS on the features above. SFS decide how many features are needed.
%It stops when the first local minimum of the cross-validation MCE is
%found.


%fsLocal = sequentialfs(classf,dataTrain(:,fs1),ystrTrain,'cv',tenfoldCVP);
load('fs_local_50.mat');


% The selected features are the following:
featuresSel=fs1(fsLocal);

%Compute the Miss Classification Error (MCE) with the selected features to evaluate the performance
testMCESFS = crossval(classf,matrixFinal(:,fs1(fsLocal)),ystr, ...
    'partition',holdoutCVP)/holdoutCVP.TestSize;


%Apply SFS again but without stop to find the absolute minimum

%[fsCVfor,historyCV] = sequentialfs(classf,dataTrain(:,fs1),ystrTrain,'cv',tenfoldCVP,'Nf',numFeat);
load('fsCVfor_historyCV_65.mat');




figure;
plot(nfs, testMCE,'o')
hold on;
plot(historyCV.Crit,'r+');
xlabel('Number of Features');
ylabel('MisClasification Error (MCE)');
legend({'Relief-F','SFS'},'location','NW');
title('Feature Selection: Relief-F and Sequential Feature Selection (SFS)');
hold on;

figure;
plot(historyCV.Crit,'r+');
xlabel('Number of Features');
ylabel('CV MCE');
title('Forward Sequential Feature Selection with cross-validation');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Select the numFeatSel looking the plot before. If the local minum is not
%the absolute one

numSelFeat=length(featuresSel);
display(numSelFeat);
numSelFeat=input('Amount of selected features: ');

fsCVfor = fs1(historyCV.In(numSelFeat,:));

%Order in which they are selected in the SFS, find the row in which they first become true in the historyCV output:
[orderlist,ignore] = find( [historyCV.In(1,:); diff(historyCV.In(1:numSelFeat,:) )]' );
fs1(orderlist);

%Compute the MCE using the selected features, the smallest MCE value is
%acheived.
testMCECVfor = crossval(classf,matrixFinal(:,fsCVfor),ystr,'partition', ...
    holdoutCVP)/holdoutCVP.TestSize; 

%Order SFS
orderSFS=fs1(orderlist);
MCEsfs=testMCECVfor;



