function [ax, ay, az, t, date]=accelData(fs, file, pathname, optPlot, optPopFile)
%function [ax, ay, az, t, date]=accelData(fs, file, pathname, optPlot, optPopFile)
%DESCRIPTION: Get the acceleration in the three axes
%INPUTS:
%   - fs: Sample frequency
%   - file: Name of the file
%   - pathname: Path of the file
%   - optPlot: 0-->No plot. 1-->Plot
%   - optPopFile: 0-->Set file and pathname. 1--> Pop to chose the desired
%   file
%RETURN:
%   - ax, ay, az: acceleration in the three axes (m/s^)
%   - t: Normalized timeStamp in seconds
%   - date: Start date data. Format equal to SQL. ex: 20140219181611
%Author: Bernat Carbons
%Modification Date: 09/05/2014



%Load the Accelerometer data file

if optPopFile
    
    [file, pathname]=uigetfile('*.dat');
end

fileComplete = fullfile(pathname, file);
    

%Get start time in hours
t0=gethour(file);

fid=fopen(fileComplete);
a=fread(fid,'short','b');
fclose(fid);

ax=a(3:5:end)/1000;
ay=a(4:5:end)/1000; 
az=a(5:5:end)/1000; 
lm=min([length(ax) length(ay) length(az)]);
ax=ax(1:lm);
ay=ay(1:lm);
az=az(1:lm);

fid=fopen(fileComplete);
a=fread(fid,'ushort','b');
fclose(fid);
t=a(1:5:end)*65536+a(2:5:end);
t=(t-t(1))/1000;
clear a;
t=t(1:lm);


%Resample data
[newData, t]=resampleData([ax,ay,az],t,fs);
ax=newData(:,1);
ay=newData(:,2);
az=newData(:,3);

filetxt = regexprep(file, '_', '-');
date=regexprep(filetxt,'AcelerometerData-','');
date=regexprep(date,'-','');
date=regexprep(date,'.dat','');
date=str2double(date)+2e13;
% %duration=t(end)/3600;


%PLOT ACCELERATION
if optPlot
    figure;
    plot(t/3600+t0,ax,'b')
    hold on
    plot(t/3600+t0,ay,'g')
    plot(t/3600+t0,az,'r')
    legend('ax','ay','az')
    xlabel('Time (h)')
    ylabel('Acceleration (m/s^2)')
    title(['Acceleration from: ' filetxt])
end






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SPECTROGRAM
atf=[ax(:) ay(:) az(:)];

window=2048;
noverlap=1024+512;
if length(ax)<window
   window=2^(floor(log2(length(ax)/8)));
   noverlap=round(window*3/4);
end
[ysp,fsp,tsp,psp]=spectrogram(atf(:,1),window,noverlap,2048,fs);
yspn=abs(ysp);
yspn=yspn/max(max(yspn));


if optPlot
    figure;
    subplot(2,1,1)
    image(tsp/3600+t0,fsp(1:300),(yspn(1:300,:).^0.3)*100)
    grid
    xlabel('Time (h)')
    ylabel('Frequency (Hz)')
    fileptxt = regexprep(file, '_', '-');
    title(['Acceleration spectrogram, file: ' fileptxt])
    
    subplot(2,1,2)
    %figure;
    image(tsp/3600+t0,fsp(1:300),psp(1:300,:));
    grid
    xlabel('Time (h)')
    ylabel('Frequency (Hz)')
    fileptxt = regexprep(file, '_', '-');
    title(['Acceleration Power Spectral Frequency, file: ' fileptxt])

end






