function [actNumber, actString, date, time, confidence]=actRecData(thr, file, pathname, optPlot, optPopFile)
%function [actNumber, actString, date, time, confidence]=actRecData(thr, file, pathname, optPlot, optPopFile)
%DESCRIPTION: Get a first appproach of the activity
%INPUTS:
%   - thr: Confidence interval threshold (1-100)
%   - file: Name of the file
%   - pathname: Path of the file
%   - optPlot: 0-->No plot. 1-->Plot
%   - optPopFile: 0-->Set file and pathname. 1--> Pop to chose the desired
%   file
%RETURN:
%   - actNumber: Selected activities in numbers
%   - actString: Selected activities in strings
%   - date: Start date data. Format equal SQL. ex: 20140219181611
%   - time: Normalized timeStamp in seconds
%   - confidence: Confidence interval in tant per cent of the acquisition
%Author: Bernat Carbons
%Modification Date: 06/05/2014



%Load Activity Recoginiton data file
if optPopFile
    
    [file, pathname]=uigetfile('*.txt');
end

fileComplete = fullfile(pathname, file);


filetxt = regexprep(file, '_', '-');

%Date
date=regexprep(filetxt,'ActData-','');
date=regexprep(date,'-','');
date=regexprep(date,'.txt','');
date=str2double(date)+2e13;

[act,confidence,time]=importfileActRec(fileComplete);
time=(time-time(1))/1000; %Time in seconds
t0=gethour(file);

%Considering a confidence interval equals to thr (INPUT)
m=find(confidence<thr);
act=act(2:end);
actNumber=zeros(1,length(time));

%Convert string to number
for in=1:length(time)
    if strcmp('still', act(in))
        %still-->1
        actNumber(in)=1;
    else if strcmp('in_vehicle',act(in))
            %in_vehicle-->2
            actNumber(in)=2;
        else if strcmp('on_bicycle',act(in))           
                %on_bicycle-->3
                actNumber(in)=3;
            else if strcmp('on_foot',act(in));
                    %on_foot-->4
                    actNumber(in)=4;
                else if strcmp('tilting',act(in));
                        %tilting-->5
                        actNumber(in)=5;
                    else
                        %unknown-->6
                        actNumber(in)=6;
                    end
                end
            end
        end
    end         
end

%Selected activities in number
if m(1)==1
    startLoop=2;
else
    startLoop=1;
end
for in=startLoop:length(m)
    actNumber(m(in))=actNumber(m(in)-1);
end


%Selected activities in string
activities={'still','in_vehicle','on_bicycle','on_foot','tilting','unknown'};
actString=cell(1,length(actNumber));
for in=1:length(activities)
    actString(actNumber==in)={activities{in}};
end


%PLOT
if optPlot
    figure;
    hold on;
    color=['k','b', 'g', 'y', 'm', 'r'];
    for in=1:6
        aux=find(actNumber==in);
        if aux>0
            stem(time(aux)/3600+t0,actNumber(aux),color(in));
        else
            stem(time(1)/3600+t0,0,color(in));
        end
    end
    legend('Still','In vehicle','On bicycle','On foot','Tilting','Unknown');
    xlabel('Time (h)')
    ylabel('Activity')
    title(['Activity approach, file ' filetxt])

end



