function [hr, trr, date]=polarData(dataAnthropoSQL,fs,idUser, file, pathname, optPlot, optPopFile)
%function [hr, trr, date]=polarData(dataAnthropoSQL,fs,idUser, file, pathname, optPlot, optPopFile)
%DESCRIPTION: Get the heart rate and a burned calories estimation
%INPUTS:
%   - dataAnthropoSQL: Antrhropometric data SQL
%   - fs: Sample frequency
%   - idUser: Desired user's identifier
%   - file: Name of the file
%   - pathname: Path of the file
%   - optPlot: 0-->No plot. 1-->Plot
%   - optPopFile: 0-->Set file and pathname. 1--> Pop to chose the desired
%   file
%Return:
%   - bpm: Heart rate in (bpm)
%   - trr: Normalized timeStamp in seconds
%   - date: Start date data. Format equal SQL. ex: 20140219181611
%Author: Bernat Carbons
%Modification Date: 09/05/2014


%Anthropometric subject data
[height,weight,age,gender,active] = get_anthroData(dataAnthropoSQL, idUser);


%Load the Polar data file

if optPopFile
    
    [file, pathname]=uigetfile('*.txt');
end

fileComplete = fullfile(pathname, file);


filetxt = regexprep(file, '_', '-');

%Date
date=regexprep(filetxt,'SerieRR-','');
date=regexprep(date,'-','');
date=regexprep(date,'.txt','');
date=str2double(date)+2e13;

[rr, time]=importfilePolar(fileComplete);

rr=rr/1000; %Convet from msec. to sec.
t=time-time(1);%Normalize
t=t/1000;

hr=60./rr; %Compute heart rate

t0=gethour(file);

trr=zeros(1,length(t));
for in=1:length(t)
    trr(in)=sum(rr(1:in));
end

%Resample data
[hr, trr]=resampleData(hr,trr,fs);
rr=[rr(1) diff(trr)];


%PLOTS


%TimeStamp Vs TimeRR
%stem(t,bpm);
% subplot(2,1,1);
% plot(t/3600+t0,hr);
% hold on;
% %xlim([t(1) t(end)]);
% % subplot(2,1,2);
% 
% plot(trr/3600+t0,hr,'r');
% %xlim([t(1) t(end)]);
% title(['Heart Rate, file: ' filetxt]);
% legend('bpmTimeStamp','bpmTimeRR');
% xlabel('Time (h)');
% ylabel('Heart Rate (bpm)');

if optPlot
    figure;
    %Suitable. trr Time
    plot(trr/3600+t0,hr);
    title(['Heart Rate, file: ' filetxt]);
    xlabel('Time (h)');
    ylabel('Heart Rate (bpm)');
    grid on;

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%CALORIES ESTIMATION. Good estimation if: 64%HRmax<HR<89%HRmax (200)

%Maximum Heart Rate. "H. Tanaka, KD. Monhan and DG Seals
hrmax=getHRmax(age);

%Mean Heart Rate
hrmean=mean(hr);
%hrmean=60;

%Find index which use the model
kcalmod=find((0.6*hrmax<=hr)&(hr<=200));

%Basal Metabolic Rate (day)
BMR=basalMR(weight,height,age,gender);

%kcal--> kcal/h
%kcal(kcalmod)=kcal(kcalmod).*(trr(kcalmod)-trr(kcalmod-1))./3600;
kcal=hr2kcal(hr(kcalmod), weight, age, gender);


%Burned Calories/hour (Basic Metabolic Rate (hour)+ kcal)
%kcalth=BMR/(24*3600)*ones(1,length(bpm)).*rr';

kcalth=BMR/24*ones(1,length(hr));
kcalth(kcalmod)=kcalth(kcalmod)+kcal;

%Total calories from model and BMR
kcaltotal=kcalth*rr'/3600;

%Burned Calories (BMR+kcal)
kcalth=1/3600*kcalth.*rr;

%PLOT
if optPlot
    kcalsum=zeros(1,length(kcalth));
    for in=1:length(kcalth)
        kcalsum(in)=sum(kcalth(1:in));
    end
    
    figure
    plot(trr/3600+t0,kcalsum);
    title(['Accumulated calories , file: ' filetxt]);
    xlabel('Time (h)');
    ylabel('Calories (kcal)');
    
    
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %PLOT Burned kcal/hour
    
    %Find the total burned calories in each hour
    ttotal=trr/3600+t0;
    for in=1:24
        kcalsumh(in)=sum(kcalth((in-1<=ttotal)&(ttotal<in)));
        kcalacum(in)=sum(kcalth(ttotal<in));
    end
    
    figure;
    %subplot(2,1,1);
    bar(1:24,kcalacum);
    grid on;
    title(['Accumulated calories , file: ' filetxt]);
    xlabel('Time (h)');
    ylabel('Calories (kcal)');
    
    %subplot(2,1,2);
    figure;
    bar(1:24,kcalsumh);
    grid on;
    title(['Burned calories/hour , file: ' filetxt]);
    xlabel('Time (h)');
    ylabel('Calories (kcal)');
    
    
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %ZONE ESTIMATION
    
    %Moderate zone 50-60%
    moder=find((0.5*hrmax<=hr)&(hr<0.6*hrmax));
    
    %Recovery (Fat burning) zone 60-70%
    rec_fat=find((0.6*hrmax<=hr)&(hr<0.7*hrmax));
    
    %Aerobic zone 70-80%
    aero=find((0.7*hrmax<=hr)&(hr<0.8*hrmax));
    
    %Anaerobix zone 80-90%
    anaero=find((0.8*hrmax<=hr)&(hr<0.9*hrmax));
    
    %Red line zone 90-100%
    redline=find((0.9*hrmax<=hr)&(hr<hrmax));
    
    %Other zone
    otherz=find(hr<0.5*hrmax);
    
    %PLOT
    figure;
    stem(trr(otherz)/3600+t0, hr(otherz),'k');
    hold on;
    stem(trr(moder)/3600+t0, hr(moder),'b');
    stem(trr(rec_fat)/3600+t0, hr(rec_fat),'g');
    stem(trr(aero)/3600+t0, hr(aero),'y');
    stem(trr(anaero)/3600+t0, hr(anaero),'m');
    stem(trr(redline)/3600+t0, hr(redline),'r');
    legend('<50%','Moderate (50-60%)','Fat (60-70%)','Aerobic (70-80%)','Anaerobic (80-90%)','Red line (>90%)');
    xlabel('Time (h)')
    ylabel('Heart Rate (bpm)')
    title(['Heart Rate Zones, file: ' filetxt])


end




