function [h, tpres, date]=preassureData(fs, file, pathname, optPlot, optPopFile)
%function [h, tpres, date]=preassureData(fs, optPlot)
%DESCRIPTION: Get the atmospheric pressure and the altitude
%INPUTS:
%   - fs: Sample frequency
%   - file: Name of the file
%   - pathname: Path of the file
%   - optPlot: 0-->No plot. 1-->Plot
%   - optPopFile: 0-->Set file and pathname. 1--> Pop to chose the desired
%   file
%RETURN:
%   - h: Altitude in meters
%   - tpres: Normalized timeStamp in seconds
%   - date: Start date data. Format equal SQL. ex: 20140219181611
%Author: Bernat Carbons
%Modification Date: 09/05/2014


%Load the atmospheric sensor data file

if optPopFile
    
    [file, pathname]=uigetfile('*.dat');
end

fileComplete = fullfile(pathname, file);



filetxt = regexprep(file, '_', '-'); 

%Date
date=regexprep(filetxt,'PreassureData-','');
date=regexprep(date,'-','');
date=regexprep(date,'.dat','');
date=str2double(date)+2e13;


%Get start time in hours
t0=gethour(file);

    
fid=fopen(fileComplete);
a=fread(fid,'uint32','b');
fclose(fid);

tpres=(a(1:2:end)-a(1))/1000; %msec-->sec
fid=fopen(fileComplete);
a=fread(fid,'float','b');
fclose(fid);
press=(a(2:2:end)); %Get the atmospheric pressure



%PLOT PRESSURE
if optPlot
    figure;
    plot(tpres/3600+t0,press);
    xlabel('Time (h)')
    ylabel('Atmospheric Pressure (hPa=mbar)')
    title(['Atmospheric Pressure from: ' filetxt]);
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%ALTITUDE

fsp=1/mean(diff(tpres));
[bp,ap]=butter(2,0.5/(fsp/2));

%Filter pressure data with low-pass Butterworth filter
pressf=filtfilt(bp,ap,press);
pressc=press;

n=find(press>(pressf+3));
pressc(n)=press(n+2);

n=find(press<(pressf-3));
pressc(n)=pressc(n+2);

pressf=filtfilt(bp,ap,pressc);


%Resample data
[pressf, tpres]=resampleData(pressf,tpres,fs);


h=(1-exp(log(pressf*100/101325)/5.25588))/(2.5577e-5);

% h=(exp(log(pressf/1013)/5.2561)-1)/6.87535e-6*0.3048;
% h=-h+mean(h(1:end));

if optPlot
    figure;
    %plot(tpres(1:10:end)/3600+t0,h(1:10:end));
    plot(tpres/3600+t0, h);
    grid
    xlabel('Time (h)')
    title(['Height (Atmospheric Pressure) from:' filetxt])
    ylabel('Altitude (m)')

end


