%Main Script
%DESCRIPTION: Main script to execute all the possible steps
%Author: Bernat Carbons
%Modification Date: 11/07/2014

clear;
close all;
clc;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SPECIFY PARAMETERS

%Select option
%option=1;%->Create QuestDataCSV (percent complete). All users jointly
%option=2;%->Create week Sum for desired user
%option=3;%->Feature Extraction.
%option=4;%->Feature Selection. 
%option=5;%->Divide data, partition (60%, 20% and 20%)
%option=6;%->Compute the algorithm creation (3 for each one)
%option=7;%->Select and algorithm among three for each type
%option=8;%->Validate the three models. Accuracy of Confusions Matrix
%option=9;%->Select the final model
%option=10;%->Test the final model

%Select the desired Model
optionModel=1;%->Decision Tree
%optionModel=2;%->Naives Bayes
%optionModel=3;%->Support Vector Machine

%Select User (50,51,60,65,77)
idUser=60;

%Questionnaire duration (in minutes)
questDur=15;

%PLOTS. Plot Accelerometer figures
optPlot=0;

%Name .csv file option 1: Percent complete questionnaires.
resfilename1='AmountOfQuestionnaries.csv';

%Name csv. file option 2: Week summary of the activities
resfilename2=strcat('WeekSummaryActivitiesMETsUser',num2str(idUser),'.csv');


%3.FEATURE EXTRACTION
%Specify parameters for obtaining data and 
%Desired sample frequency
fs=50;
%Window width (seconds)
wwidth=10;
%Small Window width (seconds)
wsmall=0.5;
%Overlap
overlap=0.5;
optionOverlap='nodelay';
%Order Filter AR coeffients
orderBurg=3;
%NumBins for Binned Distribution Feature
numBins=10;
%Number of features
numFeat=85;
%Options Feature extraction
opsFE={fs wwidth wsmall overlap optionOverlap orderBurg numBins numFeat};


%5.DATA PARTITION
algPcent=60;%Training
tunPcent=20;%Tuning
testPcent=20;%Test
numObsQuest=questDur*60/(wwidth*overlap)-1;



%6.ALGORITHM CREATION (3 for each one)
%Index part day feature
indPartDay=46;
%TREE MODEL
%Response Name
respName=strcat('ResponseIdUser',num2str(idUser));
%Number of points in the logspace to find the optimal MinLeaf
numPoints=100;
%Number used to divide the number of observations (to get the final point)
lastPoint=1000;


%Feature extraction file to load
featureExtractionFile=strcat('featureExtraction',num2str(idUser),'.mat');%featureExtractionFile=strcat('featureExtraction.mat');
%Feature selection file to load
featureSelectionFile=strcat('featureSelection',num2str(idUser),'.mat');
%Data partition
dataPartitionFile=strcat('dataPartition', num2str(idUser),'.mat');
%Trees Models File
treeModelsFile=strcat('treeModels', num2str(idUser),'.mat');
%Naive Bayes Models File
naiveBayesModelsFile=strcat('naiveBayesModels', num2str(idUser),'.mat');
%SVM Models File
svmsModelsFile=strcat('svmsModels',num2str(idUser),'.mat');
%Selected Tree
treeSelFile=strcat('treeSelected',num2str(idUser),'.mat');
%Selected Naive Bayes
naiveBayesSelFile=strcat('naiveBayesSelected', num2str(idUser),'.mat');
%Selected SVM
svmSelFile=strcat('svmSelected', num2str(idUser),'.mat');
%Validation tree
treeValFile=strcat('treeVal', num2str(idUser),'.mat');
%Validation Naive Bayes
naiveBayesValFile=strcat('naiveBayesVal', num2str(idUser),'.mat');
%Validation SVM
svmValFile=strcat('svmVal', num2str(idUser),'.mat');

    



%Labels of each column
avg={'avg(ax)','avg(ay)', 'avg(az)','avg(ax,ay,az)'};
variance={'var(ax)', 'var(ay)', 'var(az)'};
freq={'freq(ax)','freq(ay)','freq(az)'};
correl={'rxy','rxz','ryz'};
mtrend={'mt(ax)','mt(ay)','mt(az)'};
wmdiff={'wmd(ax)','wmd(ay)','wmd(az)'};
vtrend={'vt(ax)','vt(ay)','vt(az)'};
wvdiff={'wvd(ax)','wvd(ay)','wvd(az)'};
maxdifac={'mda(ax)','mda(ay)','mda(az)','mda(ax,ay,az)'};
sma={'SMA'};
ta={'TA(ax)','TA(ay)','TA(az)'};
arCoef={'AR(ax)2','AR(ax)3','AR(ax)4','AR(ax)noise','AR(ay)2','AR(ay)3', ...
    'AR(ay)4','AR(ay)noise','AR(az)2','AR(az)3','AR(az)4','AR(az)noise'};
partDay={'partDay'};
binDis=cell(3,numBins);
for in=1:numBins
    binDis{1,in}={strcat('nB(ax)',num2str(in))};
    binDis{2,in}={strcat('nB(ay)',num2str(in))};
    binDis{3,in}={strcat('nB(az)',num2str(in))};
end
energy={'Eax','Eay','Eax'};
energyU={'EUxy','EUxz','EUyz'};
entrop={'H(ax)','H(ay)','H(az)'};
name=[avg,variance,freq,correl,mtrend,wmdiff,vtrend,wvdiff,maxdifac, ...
    sma,ta,arCoef,partDay,binDis{1,1:numBins},binDis{2,1:numBins}, ...
    binDis{3,1:numBins},energy,energyU,entrop];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generic Files
%Specify the path and the name of the desired files to load
%Antrhropometric data SQL
fileAnthropoSQL = fullfile('/Users/Bernat/Dropbox/Bernat/4B/TFG/SQLite/', ...
'rsaf_anthropometricData.csv');
%Indicated activities (questionnaires) SQL
fileActivitiesSQL = fullfile('/Users/Bernat/Dropbox/Bernat/4B/TFG/SQLite/', ... 
'rsaf_indicatedActivity.csv');
%File with all the activities, their identifiers and METs
fileActivityMets = fullfile('/Users/Bernat/Dropbox/Bernat/4B/TFG/', ...
    'ActivitatsMETaccents_v2.txt');

%Load the files
[dataAnthropoSQL,dataActivitiesSQL,dataActivityMets]=loadFiles(fileAnthropoSQL, ...
    fileActivitiesSQL,fileActivityMets);

%Available users
idUsers=str2double(dataAnthropoSQL(2:end,1));
numUsers=length(idUsers);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Verify if the user exists
if isempty(find(idUsers==idUser, 1))
    beep;
    display(strcat('Error: idUser:',32,num2str(idUser),' no exist'));
    return;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Accelerometer files
pathnameAccel=strcat('/Users/Bernat/Dropbox/Bernat/4B/TFG/ArxiusRSAF/idUser', ...
    num2str(idUser),'/');
fileAccel=dir(fullfile('/Users/Bernat/Dropbox/Bernat/4B/TFG/ArxiusRSAF/', ...
    strcat('idUser',num2str(idUser),'/*.dat')));

%Load Accelerometer Data
dataAccel=loadAccelData(fileAccel, pathnameAccel, fs, optPlot);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch option
    
    %1->Create QuestDataCSV (percent complete)
    case 1    
        display(questDataCSVdoc(dataAnthropoSQL,dataActivitiesSQL,resfilename1));

        
    %2->Create week Sum for desired user
    case 2
        display(weekSumCSVdoc(dataAnthropoSQL,dataActivitiesSQL, ...
            dataActivityMets,resfilename2,idUser));
        
        
    %3->Accelerometer Data. Compute de FEATURE EXTRACTION
    case 3   

        [matrixFinal, ystr, ynum]=accelFeatureExtraction(dataAccel, ...
            dataActivitiesSQL,dataActivityMets,opsFE,idUser,optPlot,questDur);
   
        
    %4->Compute the FEATURE SELECTION
    case 4           
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Compute the feature selection
        [numSelFeat, orderSFS, MCEsfs]=accelFeatureSelection(matrixFinal, ystr);
        
        
    %5->DATA PARTITION (60%,20% and 20%)   
    case 5
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Load the Feature Selection file
        load(featureSelectionFile);
        %Partition
        [algInd, tunInd, testInd]=divideData(algPcent, tunPcent, ...
            testPcent, matrixFinal, ystr, numObsQuest); 
    
        
    %6->Compute the ALGORITHM CREATION. TRAINING
    case 6
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Load the Feature Selection file
        load(featureSelectionFile);
        %Load the Divide Data file
        load(dataPartitionFile);
        
        switch optionModel
            case 1
                %Compute the Decision Trees (3)
                [trees, crossValErrors] = accelTreesCreation(matrixFinal, ...
                    ystr, algInd, orderSFS, name, respName, numPoints, ...
                    lastPoint, indPartDay);
            case 2
                %Compute the Naives Bayes (3)
                [naiveBayes, crossValErrors] = accelNaiveBayesCreation(matrixFinal, ...
                    ystr, algInd, orderSFS, indPartDay);
            case 3
                %Scaling data
                matrixScaled = scalingData (matrixFinal, orderSFS, indPartDay);
                %Compute the Support Vectior Machines (3)
                [SVMs, SVMsParam, crossValErrors] = accelSVMCreation(matrixScaled, ynum, algInd);
                
        end
    
        
    %7->Select an algorithm among three for each type. 
    case 7
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Load the Feature Selection file
        load(featureSelectionFile);
        %Load the Divide Data file
        load(dataPartitionFile);
        
        switch optionModel
            case 1
                %Load the three trees file
                load(treeModelsFile);
                %Select the Decision Tree
                [tree, crossValError] = selectTree(trees,crossValErrors);
                
            case 2
                %Load the three Naive Bayes file
                load(naiveBayesModelsFile);
                %Select the Naive Bayes
                [naiveBayesSEL, crossValError] = selectNaiveBayes(naiveBayes,...
                    crossValErrors);

            case 3
                %Load the three SVMs file
                load(svmsModelsFile);
                %Select the Support Vector Machine
                [SVMSEL, SVMparam, crossValError] = selectSVM(SVMs, ...
                    SVMsParam, crossValErrors);
                
                
        end
        
        
        
    %8->VALIDATION
    case 8
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Load the Feature Selection file
        load(featureSelectionFile);
        %Load the Divide Data file
        load(dataPartitionFile);
        
        
        switch optionModel
            case 1
                %Load the selected tree
                load(treeSelFile);
                %Validate the selected tree
                infoAccTree = validateModel(matrixFinal, ystr, algInd, ...
                    tunInd, orderSFS, tree, numObsQuest, optionModel, 0);
                
                
            case 2
                %Load the selected Naive Bayes
                load(naiveBayesSelFile);
                %Validate the selected Naive Bayes
                infoAccNB = validateModel(matrixFinal, ystr, algInd, ...
                    tunInd, orderSFS, naiveBayesSEL, numObsQuest, optionModel, 0);
                
            case 3
                %Load the selected SVM
                load(svmSelFile);
                %Scaling data
                matrixScaled = scalingData (matrixFinal, orderSFS, indPartDay);
                %Validate the selected SVM
                infoAccSVM = validateModel(matrixScaled, ynum, algInd, ...
                    tunInd, orderSFS, SVMSEL, numObsQuest, optionModel, SVMparam);
                
        end
        
        
        
        
     %9->Select the final model
    case 9
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Load the Feature Selection file
        load(featureSelectionFile);
        %Load the Divide Data file
        load(dataPartitionFile);
        
        %Load the results of validation
        load(treeValFile);
        load(naiveBayesValFile);
        load(svmValFile);
        
        %Select the final model
        [bestModelObs, bestModelQuest] = selectFinalModel(infoAccTree, infoAccNB, infoAccSVM);

        
        
    %10->TEST the final model   
    case 10
        %Load the Feature Extraction file
        load(featureExtractionFile);
        %Load the Feature Selection file
        load(featureSelectionFile);
        %Load the Divide Data file
        load(dataPartitionFile);      
        
        switch optionModel
            case 1
                %Load the selected tree
                load(treeSelFile);
                %Validate the selected tree
                [infoObs, infoQuest] = testModel(matrixFinal, ystr, algInd, tunInd, ...
                    testInd, orderSFS, tree, numObsQuest, optionModel, dataActivityMets, ...
                    0);
                
            case 2
                %Load the selected Naive Bayes
                load(naiveBayesSelFile);
                %Validate the selected Naive Bayes
                [infoObs, infoQuest] = testModel(matrixFinal, ystr, algInd, tunInd, ...
                    testInd, orderSFS, naiveBayesSEL, numObsQuest, optionModel, dataActivityMets, ...
                    0);
                
            case 3
                %Load the selected SVM
                load(svmSelFile);
                %Scaling data
                matrixScaled = scalingData (matrixFinal, orderSFS, indPartDay);
                %Validate the selected SVM
                [infoObs, infoQuest] = testModel(matrixScaled, ynum, algInd, tunInd, ...
                    testInd, orderSFS, SVMSEL, numObsQuest, optionModel, dataActivityMets, ...
                    SVMparam);
                
        end
                   
end

beep;
